summaryrefslogtreecommitdiff
path: root/apt-pkg/indexcopy.h
diff options
context:
space:
mode:
Diffstat (limited to 'apt-pkg/indexcopy.h')
-rw-r--r--apt-pkg/indexcopy.h10
1 files changed, 8 insertions, 2 deletions
diff --git a/apt-pkg/indexcopy.h b/apt-pkg/indexcopy.h
index ee6557a3d..6fcd3b8ce 100644
--- a/apt-pkg/indexcopy.h
+++ b/apt-pkg/indexcopy.h
@@ -90,8 +90,14 @@ class SigVerify /*{{{*/
bool CopyAndVerify(string CDROM,string Name,vector<string> &SigList,
vector<string> PkgList,vector<string> SrcList);
- /** \brief generates the command to verify a file with gpgv */
- static std::vector<const char *> GetGPGVCommandLine();
+ /** \brief generates and run the command to verify a file with gpgv */
+ static bool RunGPGV(std::string const &File, std::string const &FileOut,
+ int const &statusfd, int fd[2]);
+ inline static bool RunGPGV(std::string const &File, std::string const &FileOut,
+ int const &statusfd = -1) {
+ int fd[2];
+ return RunGPGV(File, FileOut, statusfd, fd);
+ };
};
/*}}}*/